@@ -9,10 +9,10 @@ lazy_static! {
 }
 
 
-pub fn get_icon(name: &Vec<u16>, size: usize, r: u8, g: u8, b: u8) -> Option<Vec<u16>> {
+pub fn get_icon(name: &Vec<u16>, size: usize, color: Option<(u8, u8, u8)>) -> Option<Vec<u16>> {
 
     match ICONS.get(name) {
-        Some(s) => Some(self::render::format(s, size, r, g, b)),
+        Some(s) => Some(self::render::format(s, size, color)),
         _ => None
     }
 
