@@ -1,8 +1,8 @@
 use crate::consts::*;
 use crate::utils::into_v16;
 use crate::markdown::escape::undo_backslash_escape;
-use crate::markdown::inline::link::render_link;
 use crate::markdown::inline::tag::render_tag;
+use crate::markdown::math::render_math;
 
 
 pub fn render_code_spans(content: &Vec<u16>) -> Vec<u16> {
@@ -24,7 +24,7 @@ pub fn render_code_spans(content: &Vec<u16>) -> Vec<u16> {
             }
 
             else {
-                result.push(render_link(&content[last_index..ind].to_vec()));
+                result.push(render_math(&content[last_index..ind].to_vec()));
             }
 
             last_index = ind + 1;
@@ -49,7 +49,7 @@ pub fn render_code_spans(content: &Vec<u16>) -> Vec<u16> {
         last_index -= 1;
     }
 
-    result.push(render_link(&content[last_index..].to_vec()));
+    result.push(render_math(&content[last_index..].to_vec()));
     result.concat()
 }
 
