@@ -45,14 +45,20 @@ fn construct_paragraph(paragraph: Vec<&Line>) -> Line {
         for p in paragraph.iter() {
             contents.push(p.content.clone());
 
-            if p.content.len() > 2
-            && p.content[p.content.len() - 1] == U16_SPACE
-            && p.content[p.content.len() - 2] == U16_SPACE  {
-                contents.push(into_v16("<br />"));
-            }
-
-            else {
-                contents.push(vec![U16_SPACE]);
+            match is_br(&p.content) {
+                IsBr::TwoSpaces => {
+                    let mut last_content = contents.pop().unwrap();
+                    last_content = last_content[0..last_content.len() - 2].to_vec();
+                    contents.push(last_content);
+                    contents.push(into_v16("<br />"));
+                }
+                IsBr::Backslash => {
+                    let mut last_content = contents.pop().unwrap();
+                    last_content = last_content[0..last_content.len() - 1].to_vec();
+                    contents.push(last_content);
+                    contents.push(into_v16("<br />"));
+                }
+                IsBr::Nope => {contents.push(vec![U16_SPACE]);}
             }
 
         }
@@ -65,4 +71,30 @@ fn construct_paragraph(paragraph: Vec<&Line>) -> Line {
         indent: 0,
         line_type: LineType::Paragraph
     }
+}
+
+
+fn is_br(content: &Vec<u16>) -> IsBr {
+
+    if content.len() > 2
+    && content[content.len() - 1] == U16_SPACE
+    && content[content.len() - 2] == U16_SPACE {
+        IsBr::TwoSpaces
+    }
+
+    else if content.len() > 1
+    && (content[content.len() - 1] == BACKSLASH_ESCAPE_MARKER || content[content.len() - 1] == U16_BACKSLASH) {
+        IsBr::Backslash
+    }
+
+    else {
+        IsBr::Nope
+    }
+
+}
+
+enum IsBr {
+    TwoSpaces,
+    Backslash,
+    Nope
 }
\ No newline at end of file
