@@ -26,7 +26,7 @@ pub fn render_toc(lines: &Vec<Line>, headers: &Vec<Line>) -> Vec<Line> {
 
 fn is_toc(content: &Vec<u16>) -> bool {
 
-    content.iter().filter(|c| *c != &U16_SPACE).map(|c| lowercase(*c)).collect::<Vec<u16>>() == into_v16("[[toc]]")
+    lowercase_and_remove_spaces(content) == into_v16("[[toc]]")
 }
 
 
